//  Beispiel 21 "BitCoin-Kurs aus dem Internet"
//
//  Unter Verwendung der IoT Brick Library

#include <all_IoT32.h>

int counter = 0;

bool currency = false;
long old_ms = 0;

void setup()
{
  IoT_Init(true);
  IoT_TerminalWaitInit(true);
  String DeviceID = "Allnet IoT-" + hexword(rnd(65535));
  Serial.println("Device-ID = " + DeviceID);
  IoT_WLANautoConnect(DeviceID, true);                              // Verbindung, ggf. gespeicherte, über WLAN herstellen
  IoT_NTPinit();
}

void loop()
{
  if (IoT_Keypress())                                               // Wenn Taster gedrückt wird, Konfiguration zeigen
  {
    IoT_DisplayClear(10);                                           // OLED Display löschen (10 Punkt Schrift)
    String state = IoT_WLANstatus();                                // Verbindungsstatus
    if (IoT_WLANinited)                                             // Falls WLAN Verbindung erfolgreich, Status & IP anzeigen
    {
      IoT_DisplayDrawText(5, 0, "WLAN: " + IoT_WLANssid());         // WLAN Netzwerk Name
      if (state == "Connected")                                     // Wenn erfolgreich verbunden, dann Signalstärke hinzufügen
      {
        state = state + " (" + str(IoT_WLANrssi()) + "dBm)";        // Signalstärke
      }
      IoT_DisplayDrawText(5, 10, state);                            // Verbindungsstatus & Signalstärke
      IoT_DisplayDrawText(5, 20, "IP: " + IoT_WLANaddress(true));   // IP Adresse
      IoT_DisplayDrawText(5, 30, "GW: " + IoT_WLANgateway(true));   // IP Gateway
      IoT_DisplayDrawText(5, 40, "NT: " + IoT_WLANsubnet(true));    // IP Subnetzmaske
    }
    else                                                            // Falls WLAN Verbindung scheitert, Status im OLED Display anzeigen
    {
      IoT_DisplayDrawText(5, 10, state); 
    }
  }
  else
  {
    if (counter % 25 == 0)                                          // Infos seriell nicht zu oft ausgeben
    {
      if (IoT_NTPeventAvail)                                        // Zeitevent triggern
      {
        IoT_NTPprintEvent(IoT_NTPcurrentEvent);
        IoT_NTPeventAvail = false;
      }
      Serial.println(IoT_NTPdatetime() + " (" + IoT_NTPdaylightSavingTime(true) + ")");
      Serial.print("WiFi is ");
      Serial.print(IoT_WLANconnected() ? "connected" : "not connected");
      Serial.println(". Uptime: " + IoT_WLANuptime(true) + " seit " + IoT_WLANstartDatetime());
    }
    IoT_DisplayClear(16);                                           // OLED Display löschen (16 Punkt Schrift)
    IoT_DisplayAlignText(TEXT_ALIGN_CENTER);                        // Zentrierte Darstellung des Textes
    if (IoT_NTPvalid())                                             // Prüfen, ob gültige Uhrzeit aus dem Internet empfangen wurde
    {
      IoT_DisplayDrawText(63, 0, IoT_NTPtime());
      IoT_DisplayDrawText(63, 15, IoT_NTPdate());
      IoT_DisplayDrawText(63, 30, "1 Bitcoin:");
      String page = "";
      if (currency)
      {
        page = "https://iot.allnet.de/data/esp/finance/crypto/BTCEUR";
      }
      else
      {
        page = "https://iot.allnet.de/data/esp/finance/crypto/BTCUSD";
      }
      String s = strreal(realval(IoT_GetContentHTTP(page, false)), 2);
      if (currency)
      {
        IoT_DisplayDrawText(63, 45, "  " + s + " EUR  ");
      }
      else
      {
        IoT_DisplayDrawText(63, 45, "  " + s + " USD  ");
      }
    }
    else                                                            // "Bitte warten..." zentriert anzeigen
    {
      IoT_DisplayClear(24);                                         // OLED Display löschen (24 Punkt Schrift)
      IoT_DisplayAlignText(TEXT_ALIGN_CENTER);                      // Zentrierte Darstellung des Textes
      IoT_DisplayDrawText(64, 5, "Bitte");
      IoT_DisplayDrawText(64, 34, "warten...");
    }
  }
  IoT_DisplayUpdate();                                              // OLED-Anzeige aktualisieren
  delay(100);                                                       // 100 ms. warten
  counter++;
  if (old_ms + 5000 < millis())                                     // Alle 5 Sekunden die Währung wechseln
  {
    currency = not(currency);
    old_ms = millis();
  }
}

